@@ -3,7 +3,7 @@ negll <- function(p, y, x, offset) {
   theta <- p[length(p)]
   negll <- -sum(dnbinom(y,mu=exp(lp),size=theta,log=TRUE))
   if (negll>1.0e100) negll <- 1.0e100
-  if (!is.finite(negll)) browser()
+  if (!is.finite(negll)) stop("Error in calculation log likelihood")
   return(negll)
 } 
 
@@ -11,9 +11,7 @@ fitnegbin <- function(y,x,offset) {
   # obtain starting values
   pois.glm <- glm(y~x[,-1], family=poisson, offset=offset)
   initp <- c(coef(pois.glm),1)
-  # fit <- optim(initp, negll, method =  "L-BFGS-B",
-  #              lower = c(rep(-Inf,length(initp)-1),0),  hessian = FALSE, x=x, y=y, offset=offset)
   fit <- nlminb(initp, negll, lower = c(rep(-Inf,length(initp)-1),0),   x=x, y=y, offset=offset)
-  if (fit$convergence>0) browser()
+  if (fit$convergence>0) stop("Convergence failed")
   return(fit)
 }
